## Nimble - Python data science package

Nimble provides a unified framework for data science, data analysis, and machine
learning in Python that can be used as a more elegant alternative to the standard
stack (numpy, pandas, scikit-learn/sklearn, scipy, etc.). Nimble can also be used
alongside these standard tools to make it faster and easier to make predictions and
manipulate, analyze, process and visualize data.

### Getting Started

You can check the [Install](https://www.nimbledata.org/install.html) page for detailed
options or just started with this:

```
pip install nimble\[quickstart\]
```

Once Nimble is installed, you can load data in a script by calling
[`nimble.data`](https://www.nimbledata.org/docs/generated/nimble.data.html)
with a URL or local path.

```
import nimble
urlOrPath = "https://storage.googleapis.com/nimble/Metro_Interstate_Traffic_Volume.csv"
loaded = nimble.data(urlOrPath)
```

From there, you can explore the examples below or check out the the
[Cheatsheet](https://www.nimbledata.org/cheatsheet.html) and
[API Docs](https://www.nimbledata.org/docs/index.html)
to see what's possible!

### Examples

* [Cleaning Data](https://www.nimbledata.org/examples/cleaning_data.html)
* [Supervised Learning](https://www.nimbledata.org/examples/supervised_learning.html)
* [Exploring Data](https://www.nimbledata.org/examples/exploring_data.html)
* [Unsupervised Learning](https://www.nimbledata.org/examples/unsupervised_learning.html)
* [Neural Networks](https://www.nimbledata.org/neural_networks.html)
* [Merging And Tidying Data](https://www.nimbledata.org/examples/merging_and_tidying_data.html)
* [Additional Functionality](https://www.nimbledata.org/examples/additional_functionality.html)

### Resources

* [Installation](https://www.nimbledata.org/install.html)
* [API Documentation](https://www.nimbledata.org/docs/index.html)
* [Cheatsheet](https://www.nimbledata.org/cheatsheet.html)
* [Example Datasets](https://www.nimbledata.org/datasets.html)

### Contact

Feel free to get in touch with us at:

<img src="https://www.nimbledata.org/_static/sparkwave_email.png" width="334" height="30">

or through the [Nimble Github](https://github.com/willfind/nimble) page.

